@@ -3,9 +3,13 @@ test_that("Okabe Ito", {
   expect_s3_class(scale_colour_okabeito(), "ggproto")
   expect_s3_class(scale_colour_okabeito(), "ScaleDiscrete")
   expect_equal(
-    scale_colour_okabeito()$palette(8),
+    scale_colour_okabeito(black_position = "first")$palette(8),
     colour("okabe ito", names = FALSE)(8)
   )
+  expect_equal(
+    scale_colour_okabeito(black_position = "last")$palette(8),
+    colour("okabe ito black", names = FALSE)(8)
+  )
 
   expect_s3_class(scale_color_okabeito(), "ggproto")
   expect_s3_class(scale_color_okabeito(), "ScaleDiscrete")
